@@ -37,11 +37,12 @@
 #include "burn-basics.h"
 #include "burn-caps.h"
 #include "burn-track.h"
-#include "burn-medium.h"
+#include "brasero-medium.h"
 #include "burn-session.h"
 #include "burn-plugin-manager.h"
-#include "burn-drive.h"
-#include "burn-volume-obj.h"
+#include "brasero-drive.h"
+#include "brasero-volume.h"
+#include "brasero-medium-selection-priv.h"
 
 #include "brasero-dest-selection.h"
 #include "brasero-session-cfg.h"
@@ -85,15 +86,20 @@ brasero_dest_selection_lock (BraseroDestSelection *self,
 	}
 
 	if (locked) {
-		BraseroDrive *drive;
+		BraseroMedium *medium;
 
-		drive = brasero_medium_selection_get_active_drive (BRASERO_MEDIUM_SELECTION (self));
-		priv->locked_drive = drive;
+		medium = brasero_medium_selection_get_active (BRASERO_MEDIUM_SELECTION (self));
+		priv->locked_drive = brasero_medium_get_drive (medium);
 
-		if (priv->locked_drive)
+		if (priv->locked_drive) {
+			g_object_ref (priv->locked_drive);
 			brasero_drive_lock (priv->locked_drive,
 					    _("Ongoing burning process"),
 					    NULL);
+		}
+
+		if (medium)
+			g_object_unref (medium);
 	}
 }
 
@@ -102,62 +108,54 @@ brasero_dest_selection_valid_session (BraseroSessionCfg *session,
 				      BraseroDestSelection *self)
 {
 	BraseroDestSelectionPrivate *priv;
+	BraseroMedium *medium;
 	BraseroDrive *burner;
-	BraseroDrive *drive;
 
 	priv = BRASERO_DEST_SELECTION_PRIVATE (self);
 
 	/* make sure the current displayed drive reflects that */
 	burner = brasero_burn_session_get_burner (priv->session);
-	drive = brasero_medium_selection_get_active_drive (BRASERO_MEDIUM_SELECTION (self));
-	if (burner != drive) {
-		BraseroMedium *medium;
-
-		medium = brasero_drive_get_medium (drive);
+	medium = brasero_medium_selection_get_active (BRASERO_MEDIUM_SELECTION (self));
+	if (burner != brasero_medium_get_drive (medium))
 		brasero_medium_selection_set_active (BRASERO_MEDIUM_SELECTION (self), medium);
-	}
 
-	if (drive)
-		g_object_unref (drive);
+	if (medium)
+		g_object_unref (medium);
 
 	brasero_medium_selection_update_media_string (BRASERO_MEDIUM_SELECTION (self));
 }
 
 static void
-brasero_dest_selection_medium_changed (GtkComboBox *combo)
+brasero_dest_selection_medium_changed (BraseroMediumSelection *selection,
+				       BraseroMedium *medium)
 {
 	BraseroDestSelectionPrivate *priv;
-	BraseroDrive *drive;
 
-	priv = BRASERO_DEST_SELECTION_PRIVATE (combo);
+	priv = BRASERO_DEST_SELECTION_PRIVATE (selection);
 
 	if (!priv->session)
 		goto chain;
 
-	drive = brasero_medium_selection_get_active_drive (BRASERO_MEDIUM_SELECTION (combo));
-	if (!drive) {
-	    	gtk_widget_set_sensitive (GTK_WIDGET (combo), FALSE);
+	if (!medium) {
+	    	gtk_widget_set_sensitive (GTK_WIDGET (selection), FALSE);
 		goto chain;
 	}
 
-	if (drive == brasero_burn_session_get_burner (priv->session)) {
-		g_object_unref (drive);
+	if (brasero_medium_get_drive (medium) == brasero_burn_session_get_burner (priv->session))
+		goto chain;
+
+	if (priv->locked_drive && priv->locked_drive != brasero_medium_get_drive (medium)) {
+		brasero_medium_selection_set_active (selection, medium);
 		goto chain;
 	}
 
-	if (priv->locked_drive && priv->locked_drive != drive) {
-		brasero_medium_selection_set_active (BRASERO_MEDIUM_SELECTION (combo),
-						     brasero_drive_get_medium (priv->locked_drive));
-		goto chain;
-	}
-
-	brasero_burn_session_set_burner (priv->session, drive);
-	gtk_widget_set_sensitive (GTK_WIDGET (combo), (priv->locked_drive == NULL));
+	brasero_burn_session_set_burner (priv->session, brasero_medium_get_drive (medium));
+	gtk_widget_set_sensitive (GTK_WIDGET (selection), (priv->locked_drive == NULL));
 
 chain:
 
-	if (GTK_COMBO_BOX_CLASS (brasero_dest_selection_parent_class)->changed)
-		GTK_COMBO_BOX_CLASS (brasero_dest_selection_parent_class)->changed (combo);
+	if (BRASERO_MEDIUM_SELECTION_CLASS (brasero_dest_selection_parent_class)->medium_changed)
+		BRASERO_MEDIUM_SELECTION_CLASS (brasero_dest_selection_parent_class)->medium_changed (selection, medium);
 }
 
 static void
@@ -172,8 +170,8 @@ brasero_dest_selection_init (BraseroDestSelection *object)
 	/* Only show media on which we can write and which are in a burner.
 	 * There is one exception though, when we're copying media and when the
 	 * burning device is the same as the dest device. */
-	brasero_medium_selection_show_type (BRASERO_MEDIUM_SELECTION (object),
-					    BRASERO_MEDIA_TYPE_WRITABLE);
+	brasero_medium_selection_show_media_type (BRASERO_MEDIUM_SELECTION (object),
+						  BRASERO_MEDIA_TYPE_WRITABLE);
 }
 
 static void
@@ -276,7 +274,6 @@ brasero_dest_selection_set_property (GObject *object,
 {
 	BraseroDestSelectionPrivate *priv;
 	BraseroBurnSession *session;
-	BraseroDrive *drive;
 
 	priv = BRASERO_DEST_SELECTION_PRIVATE (object);
 
@@ -293,15 +290,19 @@ brasero_dest_selection_set_property (GObject *object,
 		g_object_ref (session);
 
 		if (brasero_burn_session_get_flags (session) & BRASERO_BURN_FLAG_MERGE) {
+			BraseroDrive *drive;
+
 			drive = brasero_burn_session_get_burner (session);
 			brasero_medium_selection_set_active (BRASERO_MEDIUM_SELECTION (object),
 							     brasero_drive_get_medium (drive));
 		}
 		else {
-			drive = brasero_medium_selection_get_active_drive (BRASERO_MEDIUM_SELECTION (object));
-			if (drive) {
-				brasero_burn_session_set_burner (session, drive);
-				g_object_unref (drive);
+			BraseroMedium *medium;
+
+			medium = brasero_medium_selection_get_active (BRASERO_MEDIUM_SELECTION (object));
+			if (medium) {
+				brasero_burn_session_set_burner (session, brasero_medium_get_drive (medium));
+				g_object_unref (medium);
 			}
 		}
 
@@ -389,10 +390,10 @@ brasero_dest_selection_format_medium_string (BraseroMediumSelection *selection,
 					     BraseroMedium *medium)
 {
 	gchar *label;
-	gint64 size = 0;
 	gchar *medium_name;
 	gchar *size_string;
 	BraseroMedia media;
+	gint64 size_bytes = 0;
 	BraseroBurnFlag flags;
 	BraseroTrackType input = { 0, };
 	BraseroDestSelectionPrivate *priv;
@@ -448,23 +449,29 @@ brasero_dest_selection_format_medium_string (BraseroMediumSelection *selection,
 	|| ((flags & BRASERO_BURN_FLAG_BLANK_BEFORE_WRITE)
 	&&  brasero_burn_caps_can_blank (priv->caps, priv->session) == BRASERO_BURN_OK)) {
 		brasero_medium_get_capacity (medium,
-					     &size,
+					     &size_bytes,
 					     NULL);
 	}
 	else if (flags & (BRASERO_BURN_FLAG_MERGE|BRASERO_BURN_FLAG_APPEND)) {
 		brasero_medium_get_free_space (medium,
-					       &size,
+					       &size_bytes,
 					       NULL);
 	}
 	else if (media & BRASERO_MEDIUM_CLOSED) {
-		/* NOTE for translators, the first %s is the medium name */
-		label = g_strdup_printf (_("%s: no free space"), medium_name);
-		g_free (medium_name);
-		return label;
+		if (!brasero_burn_caps_can_blank (priv->caps, priv->session) == BRASERO_BURN_OK) {
+			/* NOTE for translators, the first %s is the medium name */
+			label = g_strdup_printf (_("%s: no free space"), medium_name);
+			g_free (medium_name);
+			return label;
+		}
+
+		brasero_medium_get_capacity (medium,
+					     &size_bytes,
+					     NULL);
 	}
 	else {
 		brasero_medium_get_capacity (medium,
-					     &size,
+					     &size_bytes,
 					     NULL);
 	}
 
@@ -472,11 +479,11 @@ brasero_dest_selection_format_medium_string (BraseroMediumSelection *selection,
 	if (input.type == BRASERO_TRACK_TYPE_AUDIO
 	|| (input.type == BRASERO_TRACK_TYPE_DISC
 	&& (input.subtype.media & BRASERO_MEDIUM_HAS_AUDIO)))
-		size_string = brasero_utils_get_time_string_from_size (size,
-								       TRUE,
-								       TRUE);
+		size_string = brasero_units_get_time_string (BRASERO_BYTES_TO_DURATION (size_bytes),
+							     TRUE,
+							     TRUE);
 	else
-		size_string = g_format_size_for_display (size);
+		size_string = g_format_size_for_display (size_bytes);
 
 	/* NOTE for translators: the first %s is the medium name, the second %s
 	 * is its available free space. "Free" here is the free space available. */
@@ -491,7 +498,6 @@ static void
 brasero_dest_selection_class_init (BraseroDestSelectionClass *klass)
 {
 	GObjectClass* object_class = G_OBJECT_CLASS (klass);
-	GtkComboBoxClass *combo_box_class = GTK_COMBO_BOX_CLASS (klass);
 	BraseroMediumSelectionClass *medium_selection_class = BRASERO_MEDIUM_SELECTION_CLASS (klass);
 
 	g_type_class_add_private (klass, sizeof (BraseroDestSelectionPrivate));
@@ -500,14 +506,12 @@ brasero_dest_selection_class_init (BraseroDestSelectionClass *klass)
 	object_class->set_property = brasero_dest_selection_set_property;
 	object_class->get_property = brasero_dest_selection_get_property;
 
-	combo_box_class->changed = brasero_dest_selection_medium_changed;
-
 	medium_selection_class->format_medium_string = brasero_dest_selection_format_medium_string;
-
+	medium_selection_class->medium_changed = brasero_dest_selection_medium_changed;
 	g_object_class_install_property (object_class,
 					 PROP_SESSION,
 					 g_param_spec_object ("session",
-							      "The session to work with",
+							      "The session",
 							      "The session to work with",
 							      BRASERO_TYPE_BURN_SESSION,
 							      G_PARAM_READWRITE|G_PARAM_CONSTRUCT_ONLY));
