@@ -1,7 +1,7 @@
 /* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */
 /*
  * brasero
- * Copyright (C) Philippe Rouquier 2008 <bonfire-app@wanadoo.fr>
+ * Copyright (C) Philippe Rouquier 2005-2008 <bonfire-app@wanadoo.fr>
  * 
  * brasero is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -42,6 +42,8 @@ struct _BraseroMultiSongPropsPrivate
 	GtkWidget *artist;
 	GtkWidget *composer;
 	GtkWidget *isrc;
+
+	GtkWidget *gap_box;
 	GtkWidget *gap;
 };
 
@@ -80,7 +82,7 @@ brasero_multi_song_props_get_properties (BraseroMultiSongProps *self,
 	priv = BRASERO_MULTI_SONG_PROPS_PRIVATE (self);
 	if (artist) {
 		text = gtk_entry_get_text (GTK_ENTRY (priv->artist));
-		if (text && strcmp (text, _("<keep current values>")))
+		if (text && strcmp (text, _("<Keep current values>")))
 			*artist = g_strdup (text);
 		else
 			*artist = NULL;
@@ -88,7 +90,7 @@ brasero_multi_song_props_get_properties (BraseroMultiSongProps *self,
 
 	if (composer) {
 		text = gtk_entry_get_text (GTK_ENTRY (priv->composer));
-		if (text && strcmp (text, _("<keep current values>")))
+		if (text && strcmp (text, _("<Keep current values>")))
 			*composer = g_strdup (text);
 		else
 			*composer = NULL;
@@ -96,7 +98,7 @@ brasero_multi_song_props_get_properties (BraseroMultiSongProps *self,
 
 	if (isrc) {
 		text = gtk_entry_get_text (GTK_ENTRY (priv->isrc));
-		if (text && strcmp (text, _("<keep current values>")))
+		if (text && strcmp (text, _("<Keep current values>")))
 			*isrc = (gint) g_strtod (text, NULL);
 		else
 			*isrc = -1;
@@ -114,7 +116,7 @@ brasero_multi_song_props_gap_output_cb (GtkSpinButton *spin,
 		return FALSE;
 
 	if (gtk_spin_button_get_value (spin) == -1.0)
-		gtk_entry_set_text (GTK_ENTRY (spin), _("<keep current values>"));
+		gtk_entry_set_text (GTK_ENTRY (spin), _("<Keep current values>"));
 
 	if (gtk_spin_button_get_value (spin) == 0.0)
 		gtk_entry_set_text (GTK_ENTRY (spin), _("Remove silences"));
@@ -130,7 +132,7 @@ brasero_multi_song_props_gap_input_cb (GtkSpinButton *spin,
 	const gchar *text;
 
 	text = gtk_entry_get_text (GTK_ENTRY (spin));
-	if (text && !strcmp (text, _("<keep current values>"))) {
+	if (text && !strcmp (text, _("<Keep current values>"))) {
 		*val = -1.0;
 		return TRUE;
 	}
@@ -151,7 +153,7 @@ brasero_multi_song_props_entry_focus_out (GtkEntry *entry,
 
 	text = gtk_entry_get_text (entry);
 	if (!text || text [0] == '\0')
-		gtk_entry_set_text (entry, _("<keep current values>"));
+		gtk_entry_set_text (entry, _("<Keep current values>"));
 
 	return FALSE;
 }
@@ -164,15 +166,28 @@ brasero_multi_song_props_entry_focus_in (GtkEntry *entry,
 	const gchar *text;
 
 	text = gtk_entry_get_text (entry);
-	if (text && !strcmp (text, _("<keep current values>")))
+	if (text && !strcmp (text, _("<Keep current values>")))
 		gtk_entry_set_text (entry, "");
 
 	return FALSE;
 }
+void
+brasero_multi_song_props_set_show_gap (BraseroMultiSongProps *self,
+				       gboolean show)
+{
+	BraseroMultiSongPropsPrivate *priv;
+
+	priv = BRASERO_MULTI_SONG_PROPS_PRIVATE (self);
+	if (show)
+		gtk_widget_show (priv->gap_box);
+	else
+		gtk_widget_hide (priv->gap_box);
+}
 
 static void
 brasero_multi_song_props_init (BraseroMultiSongProps *object)
 {
+	gchar *title;
 	GtkWidget *box;
 	GtkWidget *label;
 	GtkWidget *table;
@@ -190,7 +205,10 @@ brasero_multi_song_props_init (BraseroMultiSongProps *object)
 	gtk_widget_set_tooltip_text (priv->title,
 				     _("This information will be written to the disc using CD-TEXT technology. It can be read and displayed by some audio CD players."));
 
-	frame = brasero_utils_pack_properties (_("<b>Song titles</b>"), priv->title, NULL);
+	title = g_strdup_printf ("<b>%s</b>", _("Song titles"));
+	frame = brasero_utils_pack_properties (title, priv->title, NULL);
+	g_free (title);
+
 	gtk_widget_show (frame);
 	gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (object)->vbox),
@@ -204,7 +222,10 @@ brasero_multi_song_props_init (BraseroMultiSongProps *object)
 	gtk_table_set_row_spacings (GTK_TABLE (table), 4);
 	gtk_table_set_col_spacings (GTK_TABLE (table), 6);
 
-	frame = brasero_utils_pack_properties (_("<b>Additional song information</b>"), table, NULL);
+	title = g_strdup_printf ("<b>%s</b>", _("Additional song information"));
+	frame = brasero_utils_pack_properties (title, table, NULL);
+	g_free (title);
+
 	gtk_widget_show (frame);
 	gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (object)->vbox),
@@ -220,7 +241,7 @@ brasero_multi_song_props_init (BraseroMultiSongProps *object)
 
 	priv->artist = gtk_entry_new ();
 	gtk_widget_show (priv->artist);
-	gtk_entry_set_text (GTK_ENTRY (priv->artist), _("<keep current values>"));
+	gtk_entry_set_text (GTK_ENTRY (priv->artist), _("<Keep current values>"));
 	gtk_table_attach_defaults (GTK_TABLE (table), priv->artist, 1, 2, 1, 2);
 	gtk_widget_set_tooltip_text (priv->artist,
 				     _("This information will be written to the disc using CD-TEXT technology. It can be read and displayed by some audio CD players."));
@@ -234,14 +255,14 @@ brasero_multi_song_props_init (BraseroMultiSongProps *object)
 			  G_CALLBACK (brasero_multi_song_props_entry_focus_out),
 			  NULL);
 
-	label = gtk_label_new (_("Composer:\t"));
+	label = gtk_label_new (_("Composer:"));
 	gtk_widget_show (label);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3, GTK_FILL, GTK_FILL, 0, 0);
 
 	priv->composer = gtk_entry_new ();
 	gtk_widget_show (priv->composer);
-	gtk_entry_set_text (GTK_ENTRY (priv->composer), _("<keep current values>"));
+	gtk_entry_set_text (GTK_ENTRY (priv->composer), _("<Keep current values>"));
 	gtk_table_attach_defaults (GTK_TABLE (table), priv->composer, 1, 2, 2, 3);
 	gtk_widget_set_tooltip_text (priv->composer,
 				     _("This information will be written to the disc using CD-TEXT technology. It can be read and displayed by some audio CD players."));
@@ -262,7 +283,7 @@ brasero_multi_song_props_init (BraseroMultiSongProps *object)
 
 	priv->isrc = gtk_entry_new ();
 	gtk_widget_show (priv->isrc);
-	gtk_entry_set_text (GTK_ENTRY (priv->isrc), _("<keep current values>"));
+	gtk_entry_set_text (GTK_ENTRY (priv->isrc), _("<Keep current values>"));
 	gtk_table_attach_defaults (GTK_TABLE (table), priv->isrc, 1, 2, 3, 4);
 
 	g_signal_connect (priv->isrc,
@@ -279,12 +300,16 @@ brasero_multi_song_props_init (BraseroMultiSongProps *object)
 	box = gtk_hbox_new (FALSE, 6);
 	gtk_widget_show (box);
 
-	frame = brasero_utils_pack_properties (_("<b>Options</b>"), box, NULL);
+	title = g_strdup_printf ("<b>%s</b>", _("Options"));
+	frame = brasero_utils_pack_properties (title, box, NULL);
+	g_free (title);
+	priv->gap_box = frame;
+
 	gtk_widget_show (frame);
 	gtk_container_set_border_width (GTK_CONTAINER (frame), 6);
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (object)->vbox), frame, FALSE, FALSE, 0);
 
-	label = gtk_label_new (_("Pause length:\t"));
+	label = gtk_label_new (_("Pause length:"));
 	gtk_widget_show (label);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 
