@@ -33,6 +33,7 @@
 #include "eggtreemultidnd.h"
 
 #include "burn-debug.h"
+#include "brasero-app.h"
 #include "brasero-disc.h"
 #include "brasero-io.h"
 #include "brasero-utils.h"
@@ -234,24 +235,18 @@ brasero_video_disc_directory_dialog (BraseroVideoProject *project,
 {
 	gint answer;
 	GtkWidget *dialog;
-	GtkWidget *toplevel;
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
-	dialog = gtk_message_dialog_new (GTK_WINDOW (toplevel),
-					 GTK_DIALOG_DESTROY_WITH_PARENT |
-					 GTK_DIALOG_MODAL,
-					 GTK_MESSAGE_WARNING,
-					 GTK_BUTTONS_NONE,
-					 _("Do you want to search for video files inside the directory?"));
-
-	gtk_window_set_title (GTK_WINDOW (dialog), _("Directory Search"));
+	dialog = brasero_app_dialog (brasero_app_get_default (),
+				     _("Do you want to search for video files inside the directory?"),
+				     GTK_BUTTONS_NONE,
+				     GTK_MESSAGE_WARNING);
 
 	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-						  _("Directories can't be added to video disc."));
+						  _("Directories cannot be added to video discs."));
 
 	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
 				GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-				_("Search directory"), GTK_RESPONSE_OK,
+				_("_Search Directory"), GTK_RESPONSE_OK,
 				NULL);
 
 	gtk_widget_show_all (dialog);
@@ -270,24 +265,15 @@ brasero_video_disc_unreadable_uri_dialog (BraseroVideoProject *project,
 					  const gchar *uri,
 					  BraseroVideoDisc *self)
 {
-	GtkWidget *toplevel;
 	gchar *primary;
 	gchar *name;
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
-	if (toplevel == NULL) {
-		g_warning ("Can't open file %s : %s\n",
-			   uri,
-			   error->message);
-		return;
-	}
-
 	name = g_filename_display_basename (uri);
-	primary = g_strdup_printf (_("File \"%s\" can't be opened."), name);
-	brasero_utils_message_dialog (toplevel,
-				      primary,
-				      error->message,
-				      GTK_MESSAGE_ERROR);
+	primary = g_strdup_printf (_("\"%s\" could not be opened."), name);
+	brasero_app_alert (brasero_app_get_default (),
+			   primary,
+			   error->message,
+			   GTK_MESSAGE_ERROR);
 	g_free (primary);
 	g_free (name);
 }
@@ -297,22 +283,15 @@ brasero_video_disc_not_video_dialog (BraseroVideoProject *project,
 				     const gchar *uri,
 				     BraseroVideoDisc *self)
 {
-	GtkWidget *toplevel;
 	gchar *primary;
 	gchar *name;
 
-	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
-	if (toplevel == NULL) {
-		g_warning ("Content widget error : can't handle \"%s\".\n", uri);
-		return ;
-	}
-
 	BRASERO_GET_BASENAME_FOR_DISPLAY (uri, name);
 	primary = g_strdup_printf (_("\"%s\" does not have a suitable type for video projects."), name);
-	brasero_utils_message_dialog (toplevel,
-				      primary,
-				      _("Please only add files with video contents."),
-				      GTK_MESSAGE_ERROR);
+	brasero_app_alert (brasero_app_get_default (),
+			   primary,
+			   _("Please only add files with video contents"),
+			   GTK_MESSAGE_ERROR);
 	g_free (primary);
 	g_free (name);
 }
@@ -347,6 +326,7 @@ brasero_video_disc_add_uri_real (BraseroVideoDisc *self,
 
 	file = brasero_video_project_add_uri (project,
 					      uri,
+					      NULL,
 					      sibling,
 					      start,
 					      end);
@@ -494,10 +474,10 @@ brasero_video_disc_rename_songs (GtkTreeModel *model,
 	if (!file)
 		return FALSE;
 
-	if (file->name)
-		g_free (file->name);
+	if (file->info->title)
+		g_free (file->info->title);
 
-	file->name = g_strdup (new_name);
+	file->info->title = g_strdup (new_name);
 	return TRUE;
 }
 
@@ -505,8 +485,8 @@ static void
 brasero_video_disc_edit_song_properties_list (BraseroVideoDisc *self,
 					      GList *list)
 {
-	GList *item;
 	gint isrc;
+	GList *item;
 	GList *copy;
 	GtkWidget *props;
 	GtkWidget *toplevel;
@@ -590,8 +570,12 @@ static void
 brasero_video_disc_edit_song_properties_file (BraseroVideoDisc *self,
 					      BraseroVideoFile *file)
 {
+	gint isrc;
 	gint64 end;
 	gint64 start;
+	gchar *title;
+	gchar *artist;
+	gchar *composer;
 	GtkWidget *props;
 	GtkWidget *toplevel;
 	GtkTreeModel *model;
@@ -600,7 +584,6 @@ brasero_video_disc_edit_song_properties_file (BraseroVideoDisc *self,
 
 	priv = BRASERO_VIDEO_DISC_PRIVATE (self);
 
-
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (priv->tree));
 	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (self));
 
@@ -628,24 +611,51 @@ brasero_video_disc_edit_song_properties_file (BraseroVideoDisc *self,
 	if (result != GTK_RESPONSE_ACCEPT)
 		goto end;
 
-	brasero_song_info_free (file->info);
-	file->info = g_new0 (BraseroSongInfo, 1);
-
 	brasero_song_props_get_properties (BRASERO_SONG_PROPS (props),
-					   &file->info->artist,
-					   &file->info->title,
-					   &file->info->composer,
-					   &file->info->isrc,
+					   &artist,
+					   &title,
+					   &composer,
+					   &isrc,
 					   &start,
 					   &end,
 					   NULL);
 
+	if (title) {
+		if (file->info->title)
+			g_free (file->info->title);
+
+		file->info->title = title;
+		file->title_set = TRUE;
+	}
+
+	if (artist) {
+		if (file->info->artist)
+			g_free (file->info->artist);
+
+		file->info->artist = artist;
+		file->artist_set = TRUE;
+	}
+
+	if (composer) {
+		if (file->info->composer)
+			g_free (file->info->composer);
+
+		file->info->composer = composer;
+		file->composer_set = TRUE;
+	}
+
+	if (isrc) {
+		file->info->isrc = isrc;
+		file->isrc_set = TRUE;
+	}
+
 	brasero_video_project_resize_file (BRASERO_VIDEO_PROJECT (model), file, start, end);
 
 end:
 
 	gtk_widget_destroy (props);
 }
+
 static void
 brasero_video_disc_edit_information_cb (GtkAction *action,
 					BraseroVideoDisc *self)
@@ -1297,14 +1307,16 @@ brasero_video_disc_set_property (GObject * object,
 }
 
 static BraseroDiscResult
-brasero_video_disc_get_status (BraseroDisc *self)
+brasero_video_disc_get_status (BraseroDisc *self,
+			       gint *remaining,
+			       gchar **current_task)
 {
 	BraseroVideoProject *project;
 	BraseroVideoDiscPrivate *priv;
 
 	priv = BRASERO_VIDEO_DISC_PRIVATE (self);
 	project = BRASERO_VIDEO_PROJECT (gtk_tree_view_get_model (GTK_TREE_VIEW (priv->tree)));
-	return brasero_video_project_get_status (project);
+	return brasero_video_project_get_status (project, remaining, current_task);
 }
 
 BraseroDiscResult
@@ -1342,7 +1354,7 @@ brasero_video_disc_set_session_contents (BraseroDisc *self,
 
 	priv = BRASERO_VIDEO_DISC_PRIVATE (self);
 	project = BRASERO_VIDEO_PROJECT (gtk_tree_view_get_model (GTK_TREE_VIEW (priv->tree)));
-	tracks = brasero_video_project_get_contents (project);
+	tracks = brasero_video_project_get_contents (project, FALSE);
 
 	if (!tracks)
 		return BRASERO_DISC_ERROR_EMPTY_SELECTION;
@@ -1371,11 +1383,11 @@ brasero_video_disc_get_track (BraseroDisc *disc,
 	BraseroVideoProject *project;
 	BraseroVideoDiscPrivate *priv;
 
-	disc_track->type = BRASERO_DISC_TRACK_VIDEO;
+	disc_track->type = BRASERO_PROJECT_TYPE_VIDEO;
 
 	priv = BRASERO_VIDEO_DISC_PRIVATE (disc);
 	project = BRASERO_VIDEO_PROJECT (gtk_tree_view_get_model (GTK_TREE_VIEW (priv->tree)));
-	tracks = brasero_video_project_get_contents (project);
+	tracks = brasero_video_project_get_contents (project, TRUE);
 
 	for (iter = tracks; iter; iter = iter->next) {
 		BraseroDiscSong *song;
@@ -1384,10 +1396,11 @@ brasero_video_disc_get_track (BraseroDisc *disc,
 		track = iter->data;
 
 		song = g_new0 (BraseroDiscSong, 1);
-		song->uri = brasero_track_get_audio_source (track, TRUE);;
+		song->uri = brasero_track_get_audio_source (track, TRUE);
 		song->start = brasero_track_get_audio_start (track);
 		song->end = brasero_track_get_audio_end (track);
 		song->info = brasero_song_info_copy (brasero_track_get_audio_info (track));
+
 		disc_track->contents.tracks = g_slist_append (disc_track->contents.tracks, song);
 	}
 
@@ -1405,7 +1418,7 @@ brasero_video_disc_load_track (BraseroDisc *disc,
 	BraseroVideoProject *project;
 	BraseroVideoDiscPrivate *priv;
 
-	g_return_val_if_fail (track->type == BRASERO_DISC_TRACK_VIDEO, FALSE);
+	g_return_val_if_fail (track->type == BRASERO_PROJECT_TYPE_VIDEO, FALSE);
 
 	if (track->contents.tracks == NULL)
 		return BRASERO_DISC_ERROR_EMPTY_SELECTION;
@@ -1421,6 +1434,7 @@ brasero_video_disc_load_track (BraseroDisc *disc,
 
 		brasero_video_project_add_uri (BRASERO_VIDEO_PROJECT (project),
 					       song->uri,
+					       song->info,
 					       NULL,
 					       song->start,
 					       song->end);
