@@ -51,8 +51,8 @@
 #include "burn-task-ctx.h"
 #include "burn-task.h"
 #include "burn-caps.h"
-#include "burn-volume-obj.h"
-#include "burn-drive.h"
+#include "brasero-volume.h"
+#include "brasero-drive.h"
 #include "burn-dbus.h"
 
 G_DEFINE_TYPE (BraseroBurn, brasero_burn, G_TYPE_OBJECT);
@@ -134,12 +134,9 @@ static guint brasero_burn_signals [LAST_SIGNAL] = { 0 };
 #define BRASERO_BURN_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), BRASERO_TYPE_BURN, BraseroBurnPrivate))
 
 #define MAX_EJECT_ATTEMPTS	5
-#define MAX_MOUNT_ATTEMPTS	20
+#define MAX_MOUNT_ATTEMPTS	40
 #define MOUNT_TIMEOUT		500
 
-#define MAX_LOAD_ATTEMPTS	50
-#define LOAD_TIMEOUT		500
-
 static GObjectClass *parent_class = NULL;
 
 static void
@@ -265,18 +262,15 @@ brasero_burn_eject (BraseroBurn *self,
 		    BraseroDrive *drive,
 		    GError **error)
 {
-	BraseroMedium *medium;
 	guint counter = 0;
 
-	medium = brasero_drive_get_medium (drive);
-	brasero_volume_eject (BRASERO_VOLUME (medium), TRUE, error);
+	brasero_drive_eject (drive, TRUE, error);
 
 	/* sleep some time and see what happened */
 	brasero_burn_sleep (self, 500);
-	medium = brasero_drive_get_medium (drive);
 
 	/* Retry several times, since sometimes the drives are really busy */
-	while (medium && brasero_medium_get_status (medium) != BRASERO_MEDIUM_NONE) {
+	while (brasero_drive_get_medium (drive)) {
 		counter ++;
 		if (counter > MAX_EJECT_ATTEMPTS) {
 			gchar *name;
@@ -297,9 +291,8 @@ brasero_burn_eject (BraseroBurn *self,
 		}
 
 		BRASERO_BURN_LOG ("Retrying ejection");
-		brasero_volume_eject (BRASERO_VOLUME (medium), TRUE, error);
+		brasero_drive_eject (drive, TRUE, error);
 		brasero_burn_sleep (self, 500);
-		medium = brasero_drive_get_medium (drive);
 	}
 
 	return BRASERO_BURN_OK;
@@ -341,7 +334,6 @@ brasero_burn_eject_dest_media (BraseroBurn *self,
 	}
 
 	result = brasero_burn_eject (self, priv->dest, error);
-	priv->dest = NULL;
 
 	return BRASERO_BURN_OK;
 }
@@ -988,45 +980,6 @@ again:
 	return result;
 }
 
-static BraseroBurnResult
-brasero_burn_mount_media (BraseroBurn *self,
-			  GError **error)
-{
-	guint retries = 0;
-	BraseroMedium *medium;
-	BraseroBurnPrivate *priv;
-
-	priv = BRASERO_BURN_PRIVATE (self);
-
-	/* get the mount point */
-	g_signal_emit (self,
-		       brasero_burn_signals [ACTION_CHANGED_SIGNAL],
-		       0,
-		       BRASERO_BURN_ACTION_CHECKSUM);
-
-	medium = brasero_drive_get_medium (priv->dest);
-	while (!brasero_volume_is_mounted (BRASERO_VOLUME (medium))) {
-		if (retries++ > MAX_MOUNT_ATTEMPTS) {
-			/* FIXME: there is a spelling mistake */
-			g_set_error (error,
-				     BRASERO_BURN_ERROR,
-				     BRASERO_BURN_ERROR_GENERAL,
-				     _("The disc could not be mounted (max attemps reached)"));
-			return BRASERO_BURN_ERR;
-		}
-
-		BRASERO_BURN_LOG ("Trying to mount medium");
-
-		/* NOTE: we don't really care about the return value */
-		brasero_volume_mount (BRASERO_VOLUME (medium), FALSE, NULL);
-		priv->mounted_by_us = TRUE;
-
-		brasero_burn_sleep (self, MOUNT_TIMEOUT);
-	}
-
-	return BRASERO_BURN_OK;
-}
-
 static BraseroBurnResult
 brasero_burn_lock_checksum_media (BraseroBurn *burn,
 				  GError **error)
@@ -1124,7 +1077,7 @@ brasero_burn_unlock_src_media (BraseroBurn *burn,
 	 * one thing it avoids breaking other applications that are using it
 	 * like for example totem. */
 	/* if (BRASERO_BURN_SESSION_EJECT (priv->session))
-		brasero_volume_eject (BRASERO_VOLUME (medium), FALSE, error); */
+		brasero_drive_eject (BRASERO_VOLUME (medium), FALSE, error); */
 
 	priv->src = NULL;
 	return BRASERO_BURN_OK;
@@ -1135,7 +1088,6 @@ brasero_burn_unlock_dest_media (BraseroBurn *burn,
 				GError **error)
 {
 	BraseroBurnPrivate *priv = BRASERO_BURN_PRIVATE (burn);
-	BraseroMedium *medium;
 
 	if (!priv->dest)
 		return BRASERO_BURN_OK;
@@ -1147,7 +1099,6 @@ brasero_burn_unlock_dest_media (BraseroBurn *burn,
 
 	priv->dest_locked = 0;
 	brasero_drive_unlock (priv->dest);
-	medium = brasero_drive_get_medium (priv->dest);
 
 	if (!BRASERO_BURN_SESSION_EJECT (priv->session)) {
 		if (priv->dest) {
@@ -1156,7 +1107,6 @@ brasero_burn_unlock_dest_media (BraseroBurn *burn,
 			gdrive = brasero_drive_get_gdrive (priv->dest);
 
 			/* reprobe the contents of the drive system wide */
-			BRASERO_BURN_LOG ("Reprobring drive %s", brasero_drive_get_display_name (priv->dest));
 			g_drive_poll_for_media (gdrive, NULL, NULL, NULL);
 			g_object_unref (gdrive);
 
@@ -1164,7 +1114,7 @@ brasero_burn_unlock_dest_media (BraseroBurn *burn,
 		}
 	}
 	else
-		brasero_volume_eject (BRASERO_VOLUME (medium), FALSE, error);
+		brasero_drive_eject (priv->dest, FALSE, error);
 
 	priv->dest = NULL;
 	return BRASERO_BURN_OK;
@@ -1878,17 +1828,9 @@ brasero_burn_check_real (BraseroBurn *self,
 	checksum_type = brasero_track_get_checksum_type (track);
 	brasero_track_get_type (track, &type);
 
-	/* if the input is a DISC, ask/mount/unmount and lock it (as dest) */
+	/* if the input is a DISC and there isn't any checksum specified that 
+	 * means the checksum file is on the disc. */
 	medium = brasero_drive_get_medium (priv->dest);
-	if (type.type == BRASERO_TRACK_TYPE_DISC
-	&& (checksum_type == BRASERO_CHECKSUM_MD5_FILE
-	||  checksum_type == BRASERO_CHECKSUM_SHA1_FILE
-	||  checksum_type == BRASERO_CHECKSUM_SHA256_FILE)
-	&& !brasero_volume_is_mounted (BRASERO_VOLUME (medium))) {
-		result = brasero_burn_mount_media (self, error);
-		if (result != BRASERO_BURN_OK)
-			return result;
-	}
 
 	/* get the task and run it */
 	priv->task = brasero_burn_caps_new_checksuming_task (priv->caps,
@@ -1909,20 +1851,19 @@ brasero_burn_check_real (BraseroBurn *self,
 
 		/* make sure one last time it is not mounted IF and only IF the
 		 * checksum type is NOT FILE_MD5 */
-		if (priv->dest
-		&& (checksum_type == BRASERO_CHECKSUM_MD5
-		||  checksum_type == BRASERO_CHECKSUM_SHA1
-		||  checksum_type == BRASERO_CHECKSUM_SHA256)
-		&&  brasero_volume_is_mounted (BRASERO_VOLUME (medium))
-		&& !brasero_volume_umount (BRASERO_VOLUME (medium), TRUE, NULL)) {
-			g_set_error (error,
-				     BRASERO_BURN_ERROR,
-				     BRASERO_BURN_ERROR_DRIVE_BUSY,
-				     "%s. %s",
-				     _("The drive is busy"),
-				     _("Make sure another application is not using it"));
-			return BRASERO_BURN_ERR;
-		}
+		/* it seems to work without unmounting ... */
+		/* if (medium
+		 * &&  brasero_volume_is_mounted (BRASERO_VOLUME (medium))
+		 * && !brasero_volume_umount (BRASERO_VOLUME (medium), TRUE, NULL)) {
+		 *	g_set_error (error,
+		 *		     BRASERO_BURN_ERROR,
+		 *		     BRASERO_BURN_ERROR_DRIVE_BUSY,
+		 *		     "%s. %s",
+		 *		     _("The drive is busy"),
+		 *		     _("Make sure another application is not using it"));
+		 *	return BRASERO_BURN_ERR;
+		 * }
+		 */
 
 		result = brasero_task_run (priv->task, error);
 		g_signal_emit (self,
@@ -1940,7 +1881,7 @@ brasero_burn_check_real (BraseroBurn *self,
 		priv->task = NULL;
 	}
 	else {
-		BRASERO_BURN_LOG ("the track cannot be checked");
+		BRASERO_BURN_LOG ("The track cannot be checked");
 		result = BRASERO_BURN_NOT_SUPPORTED;
 	}
 
@@ -2325,7 +2266,7 @@ brasero_burn_check (BraseroBurn *self,
 	track = tracks->data;
 	brasero_track_get_type (track, &type);
 
-	/* if the input is a DISC, ask/mount/unmount and lock it (as dest) */
+	/* if the input is a DISC, ask/check there is one and lock it (as dest) */
 	if (type.type == BRASERO_TRACK_TYPE_DISC) {
 		/* make sure there is a disc. If not, ask one and lock it */
 		result = brasero_burn_lock_checksum_media (self, error);
