@@ -594,6 +594,7 @@ brasero_checksum_image_start (BraseroJob *job,
 			      GError **error)
 {
 	BraseroChecksumImagePrivate *priv;
+	GError *thread_error = NULL;
 	BraseroJobAction action;
 
 	brasero_job_get_action (job, &action);
@@ -615,11 +616,16 @@ brasero_checksum_image_start (BraseroJob *job,
 	priv->thread = g_thread_create (brasero_checksum_image_thread,
 					BRASERO_CHECKSUM_IMAGE (job),
 					TRUE,
-					error);
+					&thread_error);
 	g_mutex_unlock (priv->mutex);
 
-	if (!priv->thread)
+	/* Reminder: this is not necessarily an error as the thread may have finished */
+	//if (!priv->thread)
+	//	return BRASERO_BURN_ERR;
+	if (thread_error) {
+		g_propagate_error (error, thread_error);
 		return BRASERO_BURN_ERR;
+	}
 
 	return BRASERO_BURN_OK;
 }
@@ -816,5 +822,7 @@ brasero_checksum_image_export_caps (BraseroPlugin *plugin, gchar **error)
 
 	brasero_plugin_add_conf_option (plugin, checksum_type);
 
+	brasero_plugin_set_compulsory (plugin, FALSE);
+
 	return BRASERO_BURN_OK;
 }
